@@ -31,6 +31,7 @@
 #define NCNN_VULKAN 1
 #define NCNN_SYSTEM_GLSLANG 1
 #define NCNN_RUNTIME_CPU 1
+#define NCNN_GNU_INLINE_ASM 1
 #define NCNN_AVX 1
 #define NCNN_XOP 1
 #define NCNN_FMA 1
@@ -42,7 +43,6 @@
 #define NCNN_AVX512BF16 1
 #define NCNN_AVX512FP16 1
 #define NCNN_VFPV4 0
-#if __aarch64__
 #define NCNN_ARM82 0
 #define NCNN_ARM82DOT 0
 #define NCNN_ARM82FP16FML 0
@@ -53,15 +53,15 @@
 #define NCNN_ARM86SVEBF16 0
 #define NCNN_ARM86SVEI8MM 0
 #define NCNN_ARM86SVEF32MM 0
-#endif // __aarch64__
 #define NCNN_MSA 0
+#define NCNN_LSX 0
 #define NCNN_MMI 0
 #define NCNN_RVV 0
 #define NCNN_INT8 1
 #define NCNN_BF16 1
 #define NCNN_FORCE_INLINE 1
 
-#define NCNN_VERSION_STRING "1.0.20220729"
+#define NCNN_VERSION_STRING "1.0.20230829"
 
 #include "ncnn_export.h"
 
